| Title: | Provide Extensions to the Prussian Army Death by Horsekick Data |
|---|---|
| Description: | We provide extensions to the classical dataset "Example 4: Death by the kick of a horse in the Prussian Army" first used by Ladislaus von Bortkeiwicz in his treatise on the Poisson distribution "Das Gesetz der kleinen Zahlen", <DOI:10.1017/S0370164600019453>. As well as an extended time series for the horse-kick death data, we also provide, in parallel, deaths by falling from a horse and by drowning. |
| Authors: | Bill Venables [aut, cre], Antony Unwin [ctb] |
| Maintainer: | Bill Venables <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0.2 |
| Built: | 2026-05-18 06:34:41 UTC |
| Source: | https://github.com/cran/Horsekicks |
The original death by horse-kick data of von Bortkiewicz, with extensions and a minor correction of an apparent transcription error in the data quoted by von Bortkiewicz. The time span is extended from 1875-1894 to 1875-1907, and deaths by falling from a horse and by drowning are also included.
hkdeathshkdeaths
A data frame with 462 rows and 8 columns:
integer: The year of the record
factor: The army corps involved
integer: The number of regiments in the corps as given by von Bortkiewicz
integer: The number of non-commissioned officer horse-kick deaths. These were included in the total numbers and only additionally separately reported up till 1899.
integer: The number of deaths by horse-kick
integer: The number of deaths by drowning
integer: The number of deaths by falling from a horse
integer: The original (shorter) horse-kick deaths series used by von Bortkiewicz, including the transcription error